==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/payment/payone_invoice.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	payone_invoice.lang.inc.php 2015-09-29
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_PAYMENT_PAYONE_INVOICE_ALLOWED_DESC' => 'Geben Sie <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_PAYONE_INVOICE_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_PAYONE_INVOICE_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt.',
	'MODULE_PAYMENT_PAYONE_INVOICE_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_PAYMENT_PAYONE_INVOICE_STATUS_DESC' => 'Möchten Sie Zahlungen über dieses Modul akzeptieren?',
	'MODULE_PAYMENT_PAYONE_INVOICE_STATUS_TITLE' => 'Modul aktivieren',
	'MODULE_PAYMENT_PAYONE_INVOICE_TEXT_DESCRIPTION' => 'Zahlung auf Rechnung über PayOne',
	'MODULE_PAYMENT_PAYONE_INVOICE_TEXT_EXTD_CONFIG' => 'Erweiterte Konfiguration',
	'MODULE_PAYMENT_PAYONE_INVOICE_TEXT_INFO' => 'Zahlung auf Rechnung',
	'MODULE_PAYMENT_PAYONE_INVOICE_TEXT_TITLE' => 'Rechnung',
	'MODULE_PAYMENT_PAYONE_INVOICE_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
	'MODULE_PAYMENT_PAYONE_INVOICE_ZONE_TITLE' => 'Zahlungszone'
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/modules/payment/payone_invoice.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	payone_invoice.lang.inc.php 2015-09-29
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_PAYMENT_PAYONE_INVOICE_ALLOWED_DESC' => 'Gib <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_PAYONE_INVOICE_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_PAYONE_INVOICE_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt.',
	'MODULE_PAYMENT_PAYONE_INVOICE_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_PAYMENT_PAYONE_INVOICE_STATUS_DESC' => 'Möchtest du Zahlungen über dieses Modul akzeptieren?',
	'MODULE_PAYMENT_PAYONE_INVOICE_STATUS_TITLE' => 'Modul aktivieren',
	'MODULE_PAYMENT_PAYONE_INVOICE_TEXT_DESCRIPTION' => 'Zahlung auf Rechnung über PayOne',
	'MODULE_PAYMENT_PAYONE_INVOICE_TEXT_EXTD_CONFIG' => 'Erweiterte Konfiguration',
	'MODULE_PAYMENT_PAYONE_INVOICE_TEXT_INFO' => 'Zahlung auf Rechnung',
	'MODULE_PAYMENT_PAYONE_INVOICE_TEXT_TITLE' => 'Rechnung',
	'MODULE_PAYMENT_PAYONE_INVOICE_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
	'MODULE_PAYMENT_PAYONE_INVOICE_ZONE_TITLE' => 'Zahlungszone'
);
